@@ -4,10 +4,16 @@ from deform.i18n import _
 from deform.widget import AutocompleteInputWidget
 from deform.widget import DateTimeInputWidget as DateTimeInputWidgetBase
 from deform.widget import SelectWidget
-from deform.widget import Widget
 from deform.widget import _normalize_choices
 import warnings
 
+try:
+    unicode
+except NameError: #pragma NO COVER
+    STRING_TYPES = (str,)
+else: #pragma NO COVER
+    STRING_TYPES = (str, bytes)
+
 
 def _normalize_optgroup_choices(values):
     result = []
@@ -86,7 +92,7 @@ class TypeaheadInputWidget(AutocompleteInputWidget):
             warnings.warn('"Source" argument is now deprecated, use "values" instead',
                 category=DeprecationWarning)
             self.values = self.source
-        if isinstance(self.values, basestring):
+        if isinstance(self.values, STRING_TYPES):
             url = self.values
             source = (
                 'function (query, process){$.getJSON("%s", {"term": query}, process);}'
@@ -142,6 +148,8 @@ class DateTimeInputWidget(DateTimeInputWidgetBase):
 
             if not _time:
                 _time = "00:00:00"
+            elif _time.count(':') == 1:
+                _time += ':00'
 
             result = ' '.join([_date, _time])
 
@@ -181,6 +189,6 @@ class ChosenMultipleWidget(SelectWidget):
     def deserialize(self, field, pstruct):
         if pstruct is null:
             return null
-        if isinstance(pstruct, basestring):
+        if isinstance(pstruct, STRING_TYPES):
             return (pstruct,)
         return tuple(pstruct)
